* What happened to this patch? (Re: [BUG] panic after umount (biscted))
@ 2007-12-14 0:38 Theodore Ts'o
2007-12-14 8:03 ` Jens Axboe
0 siblings, 1 reply; 2+ messages in thread
From: Theodore Ts'o @ 2007-12-14 0:38 UTC (permalink / raw)
To: Jens Axboe; +Cc: linux-kernel
I was going through my set of kernel patches that I've cherry picked on
LKML for my private kernel, and I noticed this hasn't gotten merged into
mainline yet. The original thread was here:
http://lkml.org/lkml/2007/10/27/61
and addressed a panic after a umount reported by Sebastian Siewior. Was
this addressed in some other way?
- Ted
diff --git a/drivers/scsi/scsi_lib.c b/drivers/scsi/scsi_lib.c
index 61fdaf0..4042269 100644
--- a/drivers/scsi/scsi_lib.c
+++ b/drivers/scsi/scsi_lib.c
@@ -1115,6 +1115,8 @@ static int scsi_init_io(struct scsi_cmnd *cmd)
* kmapping pages)
*/
cmd->use_sg = req->nr_phys_segments;
+ if (!cmd->use_sg)
+ return 0;
/*
* If sg table allocation fails, requeue request later.
@@ -1191,7 +1193,7 @@ int scsi_setup_blk_pc_cmnd(struct scsi_device *sdev, struct request *req)
if (req->bio) {
int ret;
- BUG_ON(!req->nr_phys_segments);
+ BUG_ON(!req->nr_phys_segments && req->bio->bi_size);
ret = scsi_init_io(cmd);
if (unlikely(ret))
@@ -1236,9 +1238,11 @@ int scsi_setup_fs_cmnd(struct scsi_device *sdev, struct request *req)
if (ret != BLKPREP_OK)
return ret;
/*
* Filesystem requests must transfer data.
*/
- BUG_ON(!req->nr_phys_segments);
+ if (!req->nr_phys_segments && !bio_empty_barrier(req->bio))
+ blk_dump_rq_flags(req, "scsi");
cmd = scsi_get_cmd_from_req(sdev, req);
if (unlikely(!cmd))
^ permalink raw reply related [flat|nested] 2+ messages in thread
end of thread, other threads:[~2007-12-14 8:04 UTC | newest]
Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2007-12-14 0:38 What happened to this patch? (Re: [BUG] panic after umount (biscted)) Theodore Ts'o
2007-12-14 8:03 ` Jens Axboe
This is a public inbox, see mirroring instructions
@@ -1236,9 +1238,11 @@ int scsi_setup_fs_cmnd(struct scsi_device *sdev, struct request *req)
return ret;
/*
- * Filesystem requests must transfer data.
+ * Filesystem requests must transfer data, unless it's an empty
+ * barrier.
*/
for how to clone and mirror all data and code used for this inbox